@@ -34,6 +34,13 @@
 #include "commands.h"
 #include "dialogs.h"
 
+#include "images/play.xpm"
+#include "images/pause.xpm"
+#include "images/stop.xpm"
+#include "images/team24.xpm"
+#include "images/connect.xpm"
+#include "images/disconnect.xpm"
+
 GnomeUIInfo gamemenu[] = {
     GNOMEUIINFO_ITEM(N_("_Connect to server..."), NULL, connect_command, NULL),
     GNOMEUIINFO_ITEM(N_("_Disconnect from server"), NULL, disconnect_command, NULL),
@@ -72,14 +79,14 @@ GnomeUIInfo menubar[] = {
 };
 
 GnomeUIInfo toolbar[] = {
-    GNOMEUIINFO_ITEM_STOCK(N_("Connect"), N_("Connect to a server"), connect_command, "gtk-execute"),
-    GNOMEUIINFO_ITEM_STOCK(N_("Disconnect"), N_("Disconnect from the current server"), disconnect_command, "gtk-quit"),
+    GNOMEUIINFO_ITEM_DATA(N_("Connect"), N_("Connect to a server"), connect_command, NULL, connect_xpm),
+    GNOMEUIINFO_ITEM_DATA(N_("Disconnect"), N_("Disconnect from the current server"), disconnect_command, NULL, disconnect_xpm),
     GNOMEUIINFO_SEPARATOR,
-    GNOMEUIINFO_ITEM_STOCK(N_("Start game"), N_("Start a new game"), start_command, "gtk-go-forward"),
-    GNOMEUIINFO_ITEM_STOCK(N_("Pause game"), N_("Pause the game"), pause_command, "gtk-dialog-warning"),
-    GNOMEUIINFO_ITEM_STOCK(N_("End game"), N_("End the current game"), end_command, "gtk-stop"),
+    GNOMEUIINFO_ITEM_DATA(N_("Start game"), N_("Start a new game"), start_command, NULL, play_xpm),
+    GNOMEUIINFO_ITEM_DATA(N_("End game"), N_("End the current game"), end_command, NULL, stop_xpm),
+    GNOMEUIINFO_ITEM_DATA(N_("Pause game"), N_("Pause the game"), pause_command, NULL, pause_xpm),
     GNOMEUIINFO_SEPARATOR,
-    GNOMEUIINFO_ITEM_STOCK(N_("Change team"), N_("Change your current team name"), team_command, "gtk-jump-to"),
+    GNOMEUIINFO_ITEM_DATA(N_("Change team"), N_("Change your current team name"), team_command, NULL, team24_xpm),
 #ifdef ENABLE_DETACH
     GNOMEUIINFO_SEPARATOR,
     GNOMEUIINFO_ITEM_STOCK(N_("Detach page"), N_("Detach the current notebook page"), detach_command, "gtk-cut"),
@@ -89,8 +96,25 @@ GnomeUIInfo toolbar[] = {
 
 void make_menus (GnomeApp *app)
 {
-    gnome_app_create_menus (app, menubar);
-    gnome_app_create_toolbar (app, toolbar);
+  gnome_app_create_menus (app, menubar);
+
+  gtk_accel_map_add_entry ("<GTetrinet-Main>/Game/Start", gdk_keyval_from_name ("n"), GDK_CONTROL_MASK);
+  gtk_accel_map_add_entry ("<GTetrinet-Main>/Game/Pause", gdk_keyval_from_name ("p"), GDK_CONTROL_MASK);
+  gtk_accel_map_add_entry ("<GTetrinet-Main>/Game/Stop", gdk_keyval_from_name ("s"), GDK_CONTROL_MASK);
+  gtk_accel_map_add_entry ("<GTetrinet-Main>/Game/Connect", gdk_keyval_from_name ("c"), GDK_CONTROL_MASK);
+  gtk_accel_map_add_entry ("<GTetrinet-Main>/Game/Disconnect", gdk_keyval_from_name ("d"), GDK_CONTROL_MASK);
+  gtk_accel_map_add_entry ("<GTetrinet-Main>/Game/Change_Team", gdk_keyval_from_name ("t"), GDK_CONTROL_MASK);
+  
+  gtk_menu_item_set_accel_path (GTK_MENU_ITEM (gamemenu[0].widget), "<GTetrinet-Main>/Game/Connect");
+  gtk_menu_item_set_accel_path (GTK_MENU_ITEM (gamemenu[1].widget), "<GTetrinet-Main>/Game/Disconnect");
+  gtk_menu_item_set_accel_path (GTK_MENU_ITEM (gamemenu[3].widget), "<GTetrinet-Main>/Game/Change_Team");
+  gtk_menu_item_set_accel_path (GTK_MENU_ITEM (gamemenu[5].widget), "<GTetrinet-Main>/Game/Start");
+  gtk_menu_item_set_accel_path (GTK_MENU_ITEM (gamemenu[6].widget), "<GTetrinet-Main>/Game/Pause");
+  gtk_menu_item_set_accel_path (GTK_MENU_ITEM (gamemenu[7].widget), "<GTetrinet-Main>/Game/Stop");
+
+  gnome_app_create_toolbar (app, toolbar);
+  gtk_widget_hide (toolbar[4].widget);
+  gtk_widget_hide (toolbar[1].widget);
 }
 
 /* callbacks */
@@ -119,23 +143,50 @@ void detach_command (void)
 
 void start_command (void)
 {
-    char buf[22];
-    g_snprintf (buf, sizeof(buf), "%i %i", 1, playernum);
-    client_outmessage (OUT_STARTGAME, buf);
+  char buf[22];
+  
+  g_snprintf (buf, sizeof(buf), "%i %i", 1, playernum);
+  client_outmessage (OUT_STARTGAME, buf);
+}
+
+void show_connect_button (void)
+{
+  gtk_widget_hide (toolbar[1].widget);
+  gtk_widget_show (toolbar[0].widget);
+}
+
+void show_disconnect_button (void)
+{
+  gtk_widget_hide (toolbar[0].widget);
+  gtk_widget_show (toolbar[1].widget);
+}
+
+void show_stop_button (void)
+{
+  gtk_widget_hide (toolbar[3].widget);
+  gtk_widget_show (toolbar[4].widget);
+}
+
+void show_start_button (void)
+{
+  gtk_widget_hide (toolbar[4].widget);
+  gtk_widget_show (toolbar[3].widget);
 }
 
 void end_command (void)
 {
-    char buf[22];
-    g_snprintf (buf, sizeof(buf), "%i %i", 0, playernum);
-    client_outmessage (OUT_STARTGAME, buf);
+  char buf[22];
+  
+  g_snprintf (buf, sizeof(buf), "%i %i", 0, playernum);
+  client_outmessage (OUT_STARTGAME, buf);
 }
 
 void pause_command (void)
 {
-    char buf[22];
-    g_snprintf (buf, sizeof(buf), "%i %i", paused?0:1, playernum);
-    client_outmessage (OUT_PAUSE, buf);
+  char buf[22];
+  
+  g_snprintf (buf, sizeof(buf), "%i %i", paused?0:1, playernum);
+  client_outmessage (OUT_PAUSE, buf);
 }
 
 void preferences_command (void)
